"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * @flow
 */
var react_1 = require("react");
var react_native_1 = require("react-native");
var pubsub_js_1 = require("pubsub-js");
var Theme_1 = require("../themes/Theme");
var MessageCenter_1 = require("./MessageCenter");
var DimensionUtil_1 = require("../util/DimensionUtil");
var ActionModal = (function (_super) {
    __extends(ActionModal, _super);
    function ActionModal(props) {
        var _this = _super.call(this, props) || this;
        _this.state = {
            fade: new react_native_1.Animated.Value(0),
            bottom: new react_native_1.Animated.Value(DimensionUtil_1.default.getHeight() * -1),
            isVisible: true,
            frameHeight: 0
        };
        return _this;
    }
    ActionModal.prototype.getChildContext = function () {
        var _this = this;
        return {
            messageCenter: function () {
                return _this.refs.messageCenter;
            }
        };
    };
    ActionModal.prototype.orientationChange = function () {
        var _this = this;
        this.setState({ isVisible: false }, function () {
            setTimeout(function () {
                _this.setState({ isVisible: true });
            }, 1);
        });
    };
    ActionModal.prototype.componentDidMount = function () {
        var _this = this;
        this.orientationListener = pubsub_js_1.default.subscribe('onOrientationChange', this.orientationChange.bind(this));
        requestAnimationFrame(function () {
            _this.animation = react_native_1.Animated.parallel([
                react_native_1.Animated.timing(_this.state.fade, {
                    toValue: 1,
                    delay: 200
                }),
                react_native_1.Animated.timing(_this.state.bottom, {
                    toValue: 0
                })
            ]);
            _this.animation.start();
        });
    };
    ActionModal.prototype.componentWillUnmount = function () {
        pubsub_js_1.default.unsubscribe(this.orientationListener);
        if (this.animation) {
            this.animation.stop();
        }
    };
    ActionModal.prototype.onClose = function () {
        var _this = this;
        react_native_1.Animated.parallel([
            react_native_1.Animated.timing(this.state.fade, {
                toValue: 0,
                duration: 300
            }),
            react_native_1.Animated.timing(this.state.bottom, {
                toValue: DimensionUtil_1.default.getHeight() * -1,
                duration: 200
            })
        ]).start(function () {
            if (typeof _this.props.onClose === 'function') {
                _this.props.onClose();
            }
        });
    };
    ActionModal.prototype.render = function () {
        var width = DimensionUtil_1.default.getWidth();
        var maxHeight = DimensionUtil_1.default.getHeight() - DimensionUtil_1.default.getNavigationBarFullHeight();
        return (react_1.default.createElement(react_native_1.Modal, { visible: true, onRequestClose: this.onClose.bind(this), animationType: 'none', transparent: true, supportedOrientations: [
                'portrait',
                'portrait-upside-down',
                'landscape',
                'landscape-left',
                'landscape-right'
            ], OrientationChange: function (evt) { } },
            react_1.default.createElement(react_native_1.Animated.View, { style: [styles.animation, { opacity: this.state.fade }] },
                react_1.default.createElement(react_native_1.View, { style: [styles.background] })),
            react_1.default.createElement(react_native_1.Animated.View, { style: { bottom: this.state.bottom, flex: 1 } },
                react_1.default.createElement(react_native_1.TouchableWithoutFeedback, { onPress: this.onClose.bind(this) },
                    react_1.default.createElement(react_native_1.View, { style: [styles.container] },
                        react_1.default.createElement(react_native_1.TouchableWithoutFeedback, null,
                            react_1.default.createElement(react_native_1.View, { ref: 'content', style: [
                                    styles.shadow,
                                    styles.content,
                                    this.props.style,
                                    { width: width, maxHeight: maxHeight }
                                ] },
                                this.props.title &&
                                    react_1.default.createElement(react_native_1.View, { style: styles.titleContainer },
                                        react_1.default.createElement(react_native_1.Text, { style: styles.title }, this.props.title.toUpperCase())),
                                react_1.default.createElement(react_native_1.View, { style: styles.childrenContainer }, this.props.children))),
                        react_1.default.createElement(MessageCenter_1.default, { ref: 'messageCenter' }))))));
    };
    return ActionModal;
}(react_1.Component));
ActionModal.childContextTypes = {
    messageCenter: react_1.default.PropTypes.func
};
exports.default = ActionModal;
var styles = react_native_1.StyleSheet.create({
    container: {
        flex: 1,
        justifyContent: 'flex-end',
        alignItems: 'flex-end'
    },
    animation: {
        position: 'absolute',
        top: 0,
        left: 0,
        right: 0,
        bottom: 0
    },
    background: {
        position: 'absolute',
        top: 0,
        right: 0,
        bottom: 0,
        left: 0,
        backgroundColor: Theme_1.default.vars.modalBackgroundColor
    },
    shadow: Theme_1.default.vars.shadowMedium,
    title: {
        fontSize: 12,
        textAlign: 'center',
        color: Theme_1.default.vars.modalTitleColor,
        margin: 10,
        fontWeight: '500'
    },
    titleContainer: {},
    childrenContainer: {
        padding: 5,
        paddingTop: 0,
        flexShrink: 1
        //flex:1,
    },
    content: {
        backgroundColor: Theme_1.default.vars.modalContentBackgroundColor
    }
});
